Created
December 9, 2016 20:40
-
-
Save marc1706/3661591e333b7ecfb6be3d01bd951dfa to your computer and use it in GitHub Desktop.
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
diff --git a/phpBB/styles/prosilver/style.cfg b/phpBB/styles/prosilver/style.cfg | |
index 895ee49..6701ce5 100644 | |
--- a/phpBB/styles/prosilver/style.cfg | |
+++ b/phpBB/styles/prosilver/style.cfg | |
@@ -21,8 +21,8 @@ | |
# General Information about this style | |
name = prosilver | |
copyright = © phpBB Limited, 2007 | |
-style_version = 3.2.0-RC1 | |
-phpbb_version = 3.2.0-RC1 | |
+style_version = 3.2.0-RC2 | |
+phpbb_version = 3.2.0-RC2 | |
# Defining a different template bitfield | |
# template_bitfield = lNg= | |
diff --git a/phpBB/styles/prosilver/template/confirm_delete_body.html b/phpBB/styles/prosilver/template/confirm_delete_body.html | |
index 6cbb87a..9897496 100644 | |
--- a/phpBB/styles/prosilver/template/confirm_delete_body.html | |
+++ b/phpBB/styles/prosilver/template/confirm_delete_body.html | |
@@ -7,7 +7,7 @@ | |
<label> | |
<strong>{L_DELETE_PERMANENTLY}{L_COLON}</strong> | |
<input id="delete_permanent" name="delete_permanent" type="checkbox" value="1" {S_CHECKED_PERMANENT} /> | |
- <!-- IF S_TOPIC_MODE -->{L_DELETE_TOPIC_PERMANENTLY}<!-- ELSE -->{L_DELETE_POST_PERMANENTLY}<!-- ENDIF --> | |
+ <!-- IF S_TOPIC_MODE -->{DELETE_TOPIC_PERMANENTLY_EXPLAIN}<!-- ELSE -->{DELETE_POST_PERMANENTLY_EXPLAIN}<!-- ENDIF --> | |
</label> | |
<!-- ENDIF --> | |
@@ -43,7 +43,7 @@ | |
<dd> | |
<label for="delete_permanent"> | |
<input id="delete_permanent" name="delete_permanent" type="checkbox" value="1" {S_CHECKED_PERMANENT} /> | |
- <!-- IF S_TOPIC_MODE -->{L_DELETE_TOPIC_PERMANENTLY}<!-- ELSE -->{L_DELETE_POST_PERMANENTLY}<!-- ENDIF --> | |
+ <!-- IF S_TOPIC_MODE -->{DELETE_TOPIC_PERMANENTLY_EXPLAIN}<!-- ELSE -->{DELETE_POST_PERMANENTLY_EXPLAIN}<!-- ENDIF --> | |
</label> | |
</dd> | |
</dl> | |
diff --git a/phpBB/styles/prosilver/template/forumlist_body.html b/phpBB/styles/prosilver/template/forumlist_body.html | |
index 5cbb177..0d6e930 100644 | |
--- a/phpBB/styles/prosilver/template/forumlist_body.html | |
+++ b/phpBB/styles/prosilver/template/forumlist_body.html | |
@@ -53,7 +53,7 @@ | |
<br /><strong>{forumrow.L_SUBFORUM_STR}{L_COLON}</strong> | |
<!-- BEGIN subforum --> | |
<a href="{forumrow.subforum.U_SUBFORUM}" class="subforum<!-- IF forumrow.subforum.S_UNREAD --> unread<!-- ELSE --> read<!-- ENDIF -->" title="<!-- IF forumrow.subforum.S_UNREAD -->{L_UNREAD_POSTS}<!-- ELSE -->{L_NO_UNREAD_POSTS}<!-- ENDIF -->"> | |
- <i class="icon fa-file-o fa-fw <!-- IF forumrow.subforum.S_UNREAD --> icon-red<!-- ELSE --> icon-blue<!-- ENDIF --> icon-md" aria-hidden="true"></i>{forumrow.subforum.SUBFORUM_NAME} | |
+ <i class="icon <!-- IF forumrow.subforum.IS_LINK -->fa-external-link<!-- ELSE -->fa-file-o<!-- ENDIF --> fa-fw <!-- IF forumrow.subforum.S_UNREAD --> icon-red<!-- ELSE --> icon-blue<!-- ENDIF --> icon-md" aria-hidden="true"></i>{forumrow.subforum.SUBFORUM_NAME} | |
</a> | |
<!-- IF not forumrow.subforum.S_LAST_ROW -->{L_COMMA_SEPARATOR}<!-- ENDIF --> | |
<!-- END subforum --> | |
@@ -79,12 +79,12 @@ | |
<dd class="lastpost"> | |
<span> | |
<!-- IF forumrow.U_UNAPPROVED_TOPICS --> | |
- <a href="{forumrow.U_UNAPPROVED_TOPICS}" title="{TOPICS_UNAPPROVED}"> | |
- <i class="icon fa-question fa-fw icon-blue" aria-hidden="true"></i><span class="sr-only">{TOPICS_UNAPPROVED}</span> | |
+ <a href="{forumrow.U_UNAPPROVED_TOPICS}" title="{L_TOPICS_UNAPPROVED}"> | |
+ <i class="icon fa-question fa-fw icon-blue" aria-hidden="true"></i><span class="sr-only">{L_TOPICS_UNAPPROVED}</span> | |
</a> | |
<!-- ELSEIF forumrow.U_UNAPPROVED_POSTS --> | |
- <a href="{forumrow.U_UNAPPROVED_POSTS}" title="{POSTS_UNAPPROVED_FORUM}"> | |
- <i class="icon fa-question fa-fw icon-blue" aria-hidden="true"></i><span class="sr-only">{POSTS_UNAPPROVED_FORUM}</span> | |
+ <a href="{forumrow.U_UNAPPROVED_POSTS}" title="{L_POSTS_UNAPPROVED_FORUM}"> | |
+ <i class="icon fa-question fa-fw icon-blue" aria-hidden="true"></i><span class="sr-only">{L_POSTS_UNAPPROVED_FORUM}</span> | |
</a> | |
<!-- ENDIF --> | |
<!-- IF forumrow.LAST_POST_TIME --> | |
@@ -95,8 +95,8 @@ | |
<!-- ENDIF --> | |
{L_POST_BY_AUTHOR} {forumrow.LAST_POSTER_FULL} | |
<!-- IF not S_IS_BOT --> | |
- <a href="{forumrow.U_LAST_POST}" title="{VIEW_LATEST_POST}"> | |
- <i class="icon fa-external-link-square fa-fw icon-lightgray icon-md" aria-hidden="true"></i><span class="sr-only">{VIEW_LATEST_POST}</span> | |
+ <a href="{forumrow.U_LAST_POST}" title="{L_VIEW_LATEST_POST}"> | |
+ <i class="icon fa-external-link-square fa-fw icon-lightgray icon-md" aria-hidden="true"></i><span class="sr-only">{L_VIEW_LATEST_POST}</span> | |
</a> | |
<!-- ENDIF --> | |
<br />{forumrow.LAST_POST_TIME} | |
diff --git a/phpBB/styles/prosilver/template/jumpbox.html b/phpBB/styles/prosilver/template/jumpbox.html | |
index 0c40e85..724a963 100644 | |
--- a/phpBB/styles/prosilver/template/jumpbox.html | |
+++ b/phpBB/styles/prosilver/template/jumpbox.html | |
@@ -1,49 +1,50 @@ | |
-<!-- IF S_VIEWTOPIC --> | |
+<div class="action-bar actions-jump"> | |
+ <!-- IF S_VIEWTOPIC --> | |
<p class="jumpbox-return"> | |
<a href="{U_VIEW_FORUM}" class="left-box arrow-{S_CONTENT_FLOW_BEGIN}" accesskey="r"> | |
<i class="icon fa-angle-{S_CONTENT_FLOW_BEGIN} fa-fw icon-black" aria-hidden="true"></i><span>{L_RETURN_TO_FORUM}</span> | |
</a> | |
</p> | |
-<!-- ELSEIF S_VIEWFORUM --> | |
+ <!-- ELSEIF S_VIEWFORUM --> | |
<p class="jumpbox-return"> | |
<a href="{U_INDEX}" class="left-box arrow-{S_CONTENT_FLOW_BEGIN}" accesskey="r"> | |
<i class="icon fa-angle-{S_CONTENT_FLOW_BEGIN} fa-fw icon-black" aria-hidden="true"></i><span>{L_RETURN_TO_INDEX}</span> | |
</a> | |
</p> | |
-<!-- ELSEIF SEARCH_TOPIC --> | |
+ <!-- ELSEIF SEARCH_TOPIC --> | |
<p class="jumpbox-return"> | |
<a class="left-box arrow-{S_CONTENT_FLOW_BEGIN}" href="{U_SEARCH_TOPIC}" accesskey="r"> | |
<i class="icon fa-angle-{S_CONTENT_FLOW_BEGIN} fa-fw icon-black" aria-hidden="true"></i><span>{L_RETURN_TO_TOPIC}</span> | |
</a> | |
</p> | |
-<!-- ELSEIF S_SEARCH_ACTION --> | |
+ <!-- ELSEIF S_SEARCH_ACTION --> | |
<p class="jumpbox-return"> | |
<a class="left-box arrow-{S_CONTENT_FLOW_BEGIN}" href="{U_SEARCH}" title="{L_SEARCH_ADV}" accesskey="r"> | |
<i class="icon fa-angle-{S_CONTENT_FLOW_BEGIN} fa-fw icon-black" aria-hidden="true"></i><span>{L_GO_TO_SEARCH_ADV}</span> | |
</a> | |
</p> | |
-<!-- ENDIF --> | |
- | |
-<!-- IF S_DISPLAY_JUMPBOX --> | |
+ <!-- ENDIF --> | |
+ <!-- IF S_DISPLAY_JUMPBOX --> | |
<div class="jumpbox dropdown-container dropdown-container-right<!-- IF not S_IN_MCP --> dropdown-up<!-- ENDIF --> dropdown-{S_CONTENT_FLOW_BEGIN} dropdown-button-control" id="jumpbox"> | |
- <span title="<!-- IF S_IN_MCP and S_MERGE_SELECT -->{L_SELECT_TOPICS_FROM}<!-- ELSEIF S_IN_MCP -->{L_MODERATE_FORUM}<!-- ELSE -->{L_JUMP_TO}<!-- ENDIF -->" class="button button-secondary dropdown-trigger dropdown-select"> | |
- <span><!-- IF S_IN_MCP and S_MERGE_SELECT -->{L_SELECT_TOPICS_FROM}<!-- ELSEIF S_IN_MCP -->{L_MODERATE_FORUM}<!-- ELSE -->{L_JUMP_TO}<!-- ENDIF --></span> | |
- <span class="caret"><i class="icon fa-sort-down fa-fw" aria-hidden="true"></i></span> | |
- </span> | |
+ <span title="<!-- IF S_IN_MCP and S_MERGE_SELECT -->{L_SELECT_TOPICS_FROM}<!-- ELSEIF S_IN_MCP -->{L_MODERATE_FORUM}<!-- ELSE -->{L_JUMP_TO}<!-- ENDIF -->" class="button button-secondary dropdown-trigger dropdown-select"> | |
+ <span><!-- IF S_IN_MCP and S_MERGE_SELECT -->{L_SELECT_TOPICS_FROM}<!-- ELSEIF S_IN_MCP -->{L_MODERATE_FORUM}<!-- ELSE -->{L_JUMP_TO}<!-- ENDIF --></span> | |
+ <span class="caret"><i class="icon fa-sort-down fa-fw" aria-hidden="true"></i></span> | |
+ </span> | |
<div class="dropdown"> | |
<div class="pointer"><div class="pointer-inner"></div></div> | |
<ul class="dropdown-contents"> | |
- <!-- BEGIN jumpbox_forums --> | |
+ <!-- BEGIN jumpbox_forums --> | |
<!-- IF jumpbox_forums.FORUM_ID neq -1 --> | |
- <li><a href="{jumpbox_forums.LINK}" class="<!-- IF jumpbox_forums.level -->jumpbox-sub-link<!-- ELSEIF jumpbox_forums.S_IS_CAT -->jumpbox-cat-link<!-- ELSE -->jumpbox-forum-link<!-- ENDIF -->"><!-- BEGIN level --><span class="spacer"></span><!-- END level --> <span><!-- IF jumpbox_forums.level --> ↳ <!-- ENDIF --> {jumpbox_forums.FORUM_NAME}</span></a></li> | |
+ <li><a href="{jumpbox_forums.LINK}" class="<!-- IF jumpbox_forums.level -->jumpbox-sub-link<!-- ELSEIF jumpbox_forums.S_IS_CAT -->jumpbox-cat-link<!-- ELSE -->jumpbox-forum-link<!-- ENDIF -->"><!-- BEGIN level --><span class="spacer"></span><!-- END level --> <span><!-- IF jumpbox_forums.level --> ↳ <!-- ENDIF --> {jumpbox_forums.FORUM_NAME}</span></a></li> | |
<!-- ENDIF --> | |
- <!-- END jumpbox_forums --> | |
+ <!-- END jumpbox_forums --> | |
</ul> | |
</div> | |
</div> | |
-<!-- ELSE --> | |
- <br /><br /> | |
-<!-- ENDIF --> | |
+ <!-- ELSE --> | |
+ </br></br> | |
+ <!-- ENDIF --> | |
+</div> | |
diff --git a/phpBB/styles/prosilver/template/mcp_forum.html b/phpBB/styles/prosilver/template/mcp_forum.html | |
index da0d3a4..b4ef9e6 100644 | |
--- a/phpBB/styles/prosilver/template/mcp_forum.html | |
+++ b/phpBB/styles/prosilver/template/mcp_forum.html | |
@@ -46,23 +46,23 @@ | |
<a href="{topicrow.U_VIEW_TOPIC}" class="topictitle">{topicrow.TOPIC_TITLE}</a> | |
<!-- EVENT mcp_forum_topic_title_after --> | |
<!-- IF topicrow.S_TOPIC_UNAPPROVED or topicrow.S_POSTS_UNAPPROVED --> | |
- <a href="{topicrow.U_MCP_QUEUE}" title="{TOPIC_UNAPPROVED}"> | |
- <i class="icon fa-question fa-fw icon-blue" aria-hidden="true"></i><span class="sr-only">{TOPIC_UNAPPROVED}</span> | |
+ <a href="{topicrow.U_MCP_QUEUE}" title="{L_TOPIC_UNAPPROVED}"> | |
+ <i class="icon fa-question fa-fw icon-blue" aria-hidden="true"></i><span class="sr-only">{L_TOPIC_UNAPPROVED}</span> | |
</a> | |
<!-- ENDIF --> | |
<!-- IF topicrow.S_TOPIC_DELETED or topicrow.S_POSTS_DELETED --> | |
- <a href="{topicrow.U_MCP_QUEUE}" title="{TOPIC_DELETED"> | |
- <i class="icon fa-recycle fa-fw icon-green" aria-hidden="true"></i><span class="sr-only">{TOPIC_DELETED}</span> | |
+ <a href="{topicrow.U_MCP_QUEUE}" title="{L_TOPIC_DELETED}"> | |
+ <i class="icon fa-recycle fa-fw icon-green" aria-hidden="true"></i><span class="sr-only">{L_TOPIC_DELETED}</span> | |
</a> | |
<!-- ENDIF --> | |
<!-- IF topicrow.S_TOPIC_REPORTED --> | |
- <a href="{topicrow.U_MCP_REPORT}" title="{TOPIC_REPORTED}"> | |
- <i class="icon fa-exclamation fa-fw icon-red" aria-hidden="true"></i><span class="sr-only">{TOPIC_REPORTED}</span> | |
+ <a href="{topicrow.U_MCP_REPORT}" title="{L_TOPIC_REPORTED}"> | |
+ <i class="icon fa-exclamation fa-fw icon-red" aria-hidden="true"></i><span class="sr-only">{L_TOPIC_REPORTED}</span> | |
</a> | |
<!-- ENDIF --> | |
<!-- IF topicrow.S_MOVED_TOPIC and S_CAN_DELETE --> <a href="{topicrow.U_DELETE_TOPIC}" class="topictitle">[ {L_DELETE_SHADOW_TOPIC} ]</a><!-- ENDIF --> | |
<br /> | |
- | |
+ <!-- EVENT topiclist_row_topic_title_after --> | |
<div class="responsive-show" style="display: none;"> | |
<!-- IF topicrow.ATTACH_ICON_IMG --><i class="icon fa-paperclip fa-fw" aria-hidden="true"></i> <!-- ENDIF --> | |
{L_LAST_POST} {L_POST_BY_AUTHOR} {topicrow.LAST_POST_AUTHOR_FULL} « {topicrow.LAST_POST_TIME}<br /> | |
@@ -124,6 +124,7 @@ | |
</div> | |
</div> | |
+<!-- EVENT mcp_forum_actions_before --> | |
<fieldset class="display-actions"> | |
<!-- IF not S_MERGE_SELECT --> | |
<select name="action"> | |
@@ -145,6 +146,7 @@ | |
<!-- ENDIF --> | |
{S_FORM_TOKEN} | |
</fieldset> | |
+<!-- EVENT mcp_forum_actions_after --> | |
</form> | |
<!-- INCLUDE mcp_footer.html --> | |
diff --git a/phpBB/styles/prosilver/template/mcp_move.html b/phpBB/styles/prosilver/template/mcp_move.html | |
index 876829a..45a9ae8 100644 | |
--- a/phpBB/styles/prosilver/template/mcp_move.html | |
+++ b/phpBB/styles/prosilver/template/mcp_move.html | |
@@ -31,6 +31,8 @@ | |
<!-- INCLUDE overall_header.html --> | |
+<!-- EVENT mcp_move_before --> | |
+ | |
<form id="confirm" action="{S_CONFIRM_ACTION}" method="post"> | |
<div class="panel"> | |
diff --git a/phpBB/styles/prosilver/template/mcp_post.html b/phpBB/styles/prosilver/template/mcp_post.html | |
index c7b52bb..a0de554 100644 | |
--- a/phpBB/styles/prosilver/template/mcp_post.html | |
+++ b/phpBB/styles/prosilver/template/mcp_post.html | |
@@ -102,7 +102,7 @@ | |
<!-- IF S_MESSAGE_REPORTED --> | |
<p class="post-notice reported"> | |
- <i class="icon fa-exclamation fa-fw icon-red" aria-hidden="true"></i><span class="sr-only">{TOPIC_REPORTED}</span> <a href="{U_MCP_REPORT}"><strong>{L_MESSAGE_REPORTED}</strong></a> | |
+ <i class="icon fa-exclamation fa-fw icon-red" aria-hidden="true"></i><span class="sr-only">{L_TOPIC_REPORTED}</span> <a href="{U_MCP_REPORT}"><strong>{L_MESSAGE_REPORTED}</strong></a> | |
</p> | |
<!-- ENDIF --> | |
diff --git a/phpBB/styles/prosilver/template/mcp_topic.html b/phpBB/styles/prosilver/template/mcp_topic.html | |
index 32e5f02..d64c9c9 100644 | |
--- a/phpBB/styles/prosilver/template/mcp_topic.html | |
+++ b/phpBB/styles/prosilver/template/mcp_topic.html | |
@@ -73,7 +73,7 @@ | |
<dl> | |
<dt><label for="to_topic_id">{L_MERGE_TOPIC_ID}{L_COLON}</label></dt> | |
<dd> | |
- <input class="inputbox autowidth" type="number" min="0" max="999999" name="to_topic_id" id="to_topic_id" value="{TO_TOPIC_ID}" /> | |
+ <input class="inputbox autowidth" type="number" min="0" max="9999999999" name="to_topic_id" id="to_topic_id" value="{TO_TOPIC_ID}" /> | |
<a href="{U_SELECT_TOPIC}" >{L_SELECT_TOPIC}</a> | |
</dd> | |
<!-- IF TO_TOPIC_INFO --><dd>{TO_TOPIC_INFO}</dd><!-- ENDIF --> | |
@@ -112,11 +112,15 @@ | |
</ul> | |
<h3><a href="{postrow.U_POST_DETAILS}">{postrow.POST_SUBJECT}</a></h3> | |
+ | |
+ <!-- EVENT mcp_topic_postrow_post_details_before --> | |
<p class="author"> | |
<a href="#pr{postrow.POST_ID}" title="{postrow.MINI_POST}"> | |
<i class="icon fa-file fa-fw icon-lightgray icon-tiny" aria-hidden="true"></i><span class="sr-only">{postrow.MINI_POST}</span> | |
</a> {L_POSTED} {postrow.POST_DATE} {L_POST_BY_AUTHOR} <strong>{postrow.POST_AUTHOR_FULL}</strong><!-- IF postrow.U_MCP_DETAILS --> [ <a href="{postrow.U_MCP_DETAILS}">{L_POST_DETAILS}</a> ]<!-- ENDIF --> | |
</p> | |
+ <!-- EVENT mcp_topic_postrow_post_details_after --> | |
+ | |
<!-- IF postrow.S_POST_UNAPPROVED --> | |
<p class="post-notice unapproved"> | |
<a href="{postrow.U_MCP_APPROVE}"><i class="icon fa-exclamation fa-fw icon-red" aria-hidden="true"></i><strong>{L_POST_UNAPPROVED}</strong></a> | |
diff --git a/phpBB/styles/prosilver/template/memberlist_email.html b/phpBB/styles/prosilver/template/memberlist_email.html | |
index 4a9f764..eea699d 100644 | |
--- a/phpBB/styles/prosilver/template/memberlist_email.html | |
+++ b/phpBB/styles/prosilver/template/memberlist_email.html | |
@@ -1,5 +1,7 @@ | |
<!-- INCLUDE overall_header.html --> | |
+<!-- EVENT memberlist_email_before --> | |
+ | |
<!-- IF S_CONTACT_ADMIN--> | |
<h2 class="titlespace">{L_CONTACT_ADMIN}</h2> | |
<!-- ELSEIF S_SEND_USER --> | |
diff --git a/phpBB/styles/prosilver/template/navbar_header.html b/phpBB/styles/prosilver/template/navbar_header.html | |
index 7925bd6..c300b9a 100644 | |
--- a/phpBB/styles/prosilver/template/navbar_header.html | |
+++ b/phpBB/styles/prosilver/template/navbar_header.html | |
@@ -145,14 +145,14 @@ | |
<!-- IF S_DISPLAY_PM --> | |
<li class="rightside" data-skip-responsive="true"> | |
<a href="{U_PRIVATEMSGS}" role="menuitem"> | |
- <i class="icon fa-inbox fa-fw" aria-hidden="true"></i><span><span>{L_PRIVATE_MESSAGES} [</span><strong>{PRIVATE_MESSAGE_COUNT}</strong><span>]</span></span> | |
+ <i class="icon fa-inbox fa-fw" aria-hidden="true"></i><span>{L_PRIVATE_MESSAGES} <!-- IF PRIVATE_MESSAGE_COUNT --><strong class="badge">{PRIVATE_MESSAGE_COUNT}</strong><!-- ENDIF --></span> | |
</a> | |
</li> | |
<!-- ENDIF --> | |
<!-- IF S_NOTIFICATIONS_DISPLAY --> | |
<li class="dropdown-container dropdown-{S_CONTENT_FLOW_END} rightside" data-skip-responsive="true"> | |
<a href="{U_VIEW_ALL_NOTIFICATIONS}" id="notification_list_button" class="dropdown-trigger"> | |
- <i class="icon fa-bell fa-fw" aria-hidden="true"></i><span><span>{L_NOTIFICATIONS} [</span><strong>{NOTIFICATIONS_COUNT}</strong><span>]</span></span> | |
+ <i class="icon fa-bell fa-fw" aria-hidden="true"></i><span>{L_NOTIFICATIONS} <!-- IF NOTIFICATIONS_COUNT --><strong class="badge">{NOTIFICATIONS_COUNT}</strong><!-- ENDIF --></span> | |
</a> | |
<!-- INCLUDE notification_dropdown.html --> | |
</li> | |
diff --git a/phpBB/styles/prosilver/template/overall_header.html b/phpBB/styles/prosilver/template/overall_header.html | |
index 8a3eb65..4a31a0a 100644 | |
--- a/phpBB/styles/prosilver/template/overall_header.html | |
+++ b/phpBB/styles/prosilver/template/overall_header.html | |
@@ -76,6 +76,7 @@ | |
<a id="top" class="top-anchor" accesskey="t"></a> | |
<div id="page-header"> | |
<div class="headerbar" role="banner"> | |
+ <!-- EVENT overall_header_headerbar_before --> | |
<div class="inner"> | |
<div id="site-description" class="site-description"> | |
@@ -102,8 +103,10 @@ | |
</form> | |
</div> | |
<!-- ENDIF --> | |
+ <!-- EVENT overall_header_searchbox_after --> | |
</div> | |
+ <!-- EVENT overall_header_headerbar_after --> | |
</div> | |
<!-- EVENT overall_header_navbar_before --> | |
<!-- INCLUDE navbar_header.html --> | |
diff --git a/phpBB/styles/prosilver/template/posting_attach_body.html b/phpBB/styles/prosilver/template/posting_attach_body.html | |
index da527e9..618ac95 100644 | |
--- a/phpBB/styles/prosilver/template/posting_attach_body.html | |
+++ b/phpBB/styles/prosilver/template/posting_attach_body.html | |
@@ -7,7 +7,7 @@ | |
<dl> | |
<dt><label for="fileupload">{L_FILENAME}{L_COLON}</label></dt> | |
<dd> | |
- <input type="file" name="fileupload" id="fileupload" maxlength="{FILESIZE}" value="" class="inputbox autowidth" /> | |
+ <input type="file" name="fileupload" id="fileupload" class="inputbox autowidth" /> | |
<input type="submit" name="add_file" value="{L_ADD_FILE}" class="button2" onclick="upload = true;" /> | |
</dd> | |
</dl> | |
diff --git a/phpBB/styles/prosilver/template/posting_editor.html b/phpBB/styles/prosilver/template/posting_editor.html | |
index 0d526cd..d963c98 100644 | |
--- a/phpBB/styles/prosilver/template/posting_editor.html | |
+++ b/phpBB/styles/prosilver/template/posting_editor.html | |
@@ -23,7 +23,11 @@ | |
<!-- IF S_POST_ACTION or S_PRIVMSGS or S_EDIT_DRAFT --> | |
<dl style="clear: left;"> | |
<dt><label for="subject">{L_SUBJECT}{L_COLON}</label></dt> | |
- <dd><input type="text" name="subject" id="subject" size="45" maxlength="<!-- IF S_NEW_MESSAGE -->120<!-- ELSE -->124<!-- ENDIF -->" tabindex="2" value="{SUBJECT}{DRAFT_SUBJECT}" class="inputbox autowidth" /></dd> | |
+ <dd> | |
+ <!-- EVENT posting_editor_subject_prepend --> | |
+ <input type="text" name="subject" id="subject" size="45" maxlength="<!-- IF S_NEW_MESSAGE -->120<!-- ELSE -->124<!-- ENDIF -->" tabindex="2" value="{SUBJECT}{DRAFT_SUBJECT}" class="inputbox autowidth" /> | |
+ <!-- EVENT posting_editor_subject_append --> | |
+ </dd> | |
</dl> | |
<!-- IF CAPTCHA_TEMPLATE and S_CONFIRM_CODE --> | |
<!-- DEFINE $CAPTCHA_TAB_INDEX = 3 --> | |
diff --git a/phpBB/styles/prosilver/template/posting_topic_review.html b/phpBB/styles/prosilver/template/posting_topic_review.html | |
index dae0095..857c686 100644 | |
--- a/phpBB/styles/prosilver/template/posting_topic_review.html | |
+++ b/phpBB/styles/prosilver/template/posting_topic_review.html | |
@@ -16,6 +16,10 @@ | |
<div class="post bg3 post-ignore"> | |
<div class="inner"> | |
{topic_review_row.L_IGNORE_POST} | |
+ <!-- ELSE IF topic_review_row.S_POST_DELETED --> | |
+ <div class="post bg3 post-ignore"> | |
+ <div class="inner"> | |
+ {topic_review_row.L_DELETE_POST} | |
<!-- ELSE --> | |
<div class="post <!-- IF topic_review_row.S_ROW_COUNT is odd -->bg1<!-- ELSE -->bg2<!-- ENDIF --><!-- IF topic_review_row.POST_ID == REPORTED_POST_ID --> reported<!-- ENDIF -->"> | |
<div class="inner"> | |
@@ -43,6 +47,7 @@ | |
</ul> | |
<!-- ENDIF --> | |
+ <!-- EVENT posting_topic_review_row_post_details_before --> | |
<p class="author"> | |
<!-- IF S_IS_BOT --> | |
<span><i class="icon fa-file fa-fw icon-lightgray icon-md" aria-hidden="true"></i><span class="sr-only">{topic_review_row.MINI_POST}</span></span> | |
@@ -53,6 +58,8 @@ | |
<!-- ENDIF --> | |
{L_POST_BY_AUTHOR} <strong>{topic_review_row.POST_AUTHOR_FULL}</strong> » {topic_review_row.POST_DATE} | |
</p> | |
+ <!-- EVENT posting_topic_review_row_post_details_after --> | |
+ | |
<div class="content">{topic_review_row.MESSAGE}</div> | |
<!-- IF topic_review_row.S_HAS_ATTACHMENTS --> | |
diff --git a/phpBB/styles/prosilver/template/search_results.html b/phpBB/styles/prosilver/template/search_results.html | |
index ea558fd..f711456 100644 | |
--- a/phpBB/styles/prosilver/template/search_results.html | |
+++ b/phpBB/styles/prosilver/template/search_results.html | |
@@ -84,23 +84,23 @@ | |
<!-- EVENT topiclist_row_prepend --> | |
<!-- IF searchresults.S_UNREAD_TOPIC and not S_IS_BOT --> | |
<a class="unread" href="{searchresults.U_NEWEST_POST}"> | |
- <i class="icon fa-file fa-fw icon-red icon-md" aria-hidden="true"></i><span class="sr-only">{NEW_POST}</span> | |
+ <i class="icon fa-file fa-fw icon-red icon-md" aria-hidden="true"></i><span class="sr-only">{L_NEW_POST}</span> | |
</a> | |
<!-- ENDIF --> | |
<a href="{searchresults.U_VIEW_TOPIC}" class="topictitle">{searchresults.TOPIC_TITLE}</a> | |
<!-- IF searchresults.S_TOPIC_UNAPPROVED or searchresults.S_POSTS_UNAPPROVED --> | |
- <a href="{searchresults.U_MCP_QUEUE}" title="{TOPIC_UNAPPROVED}"> | |
- <i class="icon fa-question fa-fw icon-blue" aria-hidden="true"></i><span class="sr-only">{TOPIC_UNAPPROVED}</span> | |
+ <a href="{searchresults.U_MCP_QUEUE}" title="{L_TOPIC_UNAPPROVED}"> | |
+ <i class="icon fa-question fa-fw icon-blue" aria-hidden="true"></i><span class="sr-only">{L_TOPIC_UNAPPROVED}</span> | |
</a> | |
<!-- ENDIF --> | |
<!-- IF searchresults.S_TOPIC_DELETED --> | |
- <a href="{searchresults.U_MCP_QUEUE}" title="{TOPIC_DELETED}"> | |
- <i class="icon fa-recycle fa-fw icon-green" aria-hidden="true"></i><span class="sr-only">{TOPIC_DELETED}</span> | |
+ <a href="{searchresults.U_MCP_QUEUE}" title="{L_TOPIC_DELETED}"> | |
+ <i class="icon fa-recycle fa-fw icon-green" aria-hidden="true"></i><span class="sr-only">{L_TOPIC_DELETED}</span> | |
</a> | |
<!-- ENDIF --> | |
<!-- IF searchresults.S_TOPIC_REPORTED --> | |
- <a href="{searchresults.U_MCP_REPORT}" title="{TOPIC_REPORTED}"> | |
- <i class="icon fa-exclamation fa-fw icon-red" aria-hidden="true"></i><span class="sr-only">{TOPIC_REPORTED}</span> | |
+ <a href="{searchresults.U_MCP_REPORT}" title="{L_TOPIC_REPORTED}"> | |
+ <i class="icon fa-exclamation fa-fw icon-red" aria-hidden="true"></i><span class="sr-only">{L_TOPIC_REPORTED}</span> | |
</a> | |
<!-- ENDIF --> | |
<br /> | |
@@ -134,6 +134,7 @@ | |
</ul> | |
</div> | |
<!-- ENDIF --> | |
+ <!-- EVENT topiclist_row_topic_title_after --> | |
<!-- EVENT topiclist_row_append --> | |
</div> | |
diff --git a/phpBB/styles/prosilver/template/ucp_main_bookmarks.html b/phpBB/styles/prosilver/template/ucp_main_bookmarks.html | |
index c4b7abd..25647af 100644 | |
--- a/phpBB/styles/prosilver/template/ucp_main_bookmarks.html | |
+++ b/phpBB/styles/prosilver/template/ucp_main_bookmarks.html | |
@@ -44,13 +44,13 @@ | |
</a> | |
<!-- ENDIF --><a href="{topicrow.U_VIEW_TOPIC}" class="topictitle">{topicrow.TOPIC_TITLE}</a> | |
<!-- IF topicrow.S_TOPIC_UNAPPROVED or topicrow.S_POSTS_UNAPPROVED --> | |
- <a href="{topicrow.U_MCP_QUEUE}" title="{TOPIC_UNAPPROVED}"> | |
- <i class="icon fa-question fa-fw icon-blue" aria-hidden="true"></i><span class="sr-only">{TOPIC_UNAPPROVED}</span> | |
+ <a href="{topicrow.U_MCP_QUEUE}" title="{L_TOPIC_UNAPPROVED}"> | |
+ <i class="icon fa-question fa-fw icon-blue" aria-hidden="true"></i><span class="sr-only">{L_TOPIC_UNAPPROVED}</span> | |
</a> | |
<!-- ENDIF --> | |
<!-- IF topicrow.S_TOPIC_REPORTED --> | |
- <a href="{topicrow.U_MCP_REPORT}" title="{TOPIC_REPORTED}"> | |
- <i class="icon fa-exclamation fa-fw icon-red" aria-hidden="true"></i><span class="sr-only">{TOPIC_REPORTED}</span> | |
+ <a href="{topicrow.U_MCP_REPORT}" title="{L_TOPIC_REPORTED}"> | |
+ <i class="icon fa-exclamation fa-fw icon-red" aria-hidden="true"></i><span class="sr-only">{L_TOPIC_REPORTED}</span> | |
</a> | |
<!-- ENDIF --> | |
<br /> | |
diff --git a/phpBB/styles/prosilver/template/ucp_main_subscribed.html b/phpBB/styles/prosilver/template/ucp_main_subscribed.html | |
index 03c06b8..d8de7fd 100644 | |
--- a/phpBB/styles/prosilver/template/ucp_main_subscribed.html | |
+++ b/phpBB/styles/prosilver/template/ucp_main_subscribed.html | |
@@ -30,7 +30,7 @@ | |
{forumrow.FORUM_DESC} | |
<!-- IF forumrow.LAST_POST_TIME --> | |
<div class="responsive-show" style="display: none;"> | |
- {L_LAST_POST} {L_POST_BY_AUTHOR} {forumrow.LAST_POST_AUTHOR_FULL} « <a href="{topicrow.U_LAST_POST}">{forumrow.LAST_POST_TIME}</a> | |
+ {L_LAST_POST} {L_POST_BY_AUTHOR} {forumrow.LAST_POST_AUTHOR_FULL} « <a href="{forumrow.U_LAST_POST}">{forumrow.LAST_POST_TIME}</a> | |
</div> | |
<!-- ENDIF --> | |
</div> | |
@@ -87,13 +87,13 @@ | |
</a> | |
<!-- ENDIF --><a href="{topicrow.U_VIEW_TOPIC}" class="topictitle">{topicrow.TOPIC_TITLE}</a> | |
<!-- IF topicrow.S_TOPIC_UNAPPROVED or topicrow.S_POSTS_UNAPPROVED --> | |
- <a href="{topicrow.U_MCP_QUEUE}" title="{TOPIC_UNAPPROVED}"> | |
- <i class="icon fa-question fa-fw icon-blue" aria-hidden="true"></i><span class="sr-only">{TOPIC_UNAPPROVED}</span> | |
+ <a href="{topicrow.U_MCP_QUEUE}" title="{L_TOPIC_UNAPPROVED}"> | |
+ <i class="icon fa-question fa-fw icon-blue" aria-hidden="true"></i><span class="sr-only">{L_TOPIC_UNAPPROVED}</span> | |
</a> | |
<!-- ENDIF --> | |
<!-- IF topicrow.S_TOPIC_REPORTED --> | |
- <a href="{topicrow.U_MCP_REPORT}" title="{TOPIC_REPORTED}"> | |
- <i class="icon fa-exclamation fa-fw icon-red" aria-hidden="true"></i><span class="sr-only">{TOPIC_REPORTED}</span> | |
+ <a href="{topicrow.U_MCP_REPORT}" title="{L_TOPIC_REPORTED}"> | |
+ <i class="icon fa-exclamation fa-fw icon-red" aria-hidden="true"></i><span class="sr-only">{L_TOPIC_REPORTED}</span> | |
</a> | |
<!-- ENDIF --> | |
<br /> | |
diff --git a/phpBB/styles/prosilver/template/viewforum_body.html b/phpBB/styles/prosilver/template/viewforum_body.html | |
index 05f57ee..9824989 100644 | |
--- a/phpBB/styles/prosilver/template/viewforum_body.html | |
+++ b/phpBB/styles/prosilver/template/viewforum_body.html | |
@@ -126,6 +126,8 @@ | |
<!-- ENDIF --> | |
+<!-- EVENT viewforum_body_topic_row_before --> | |
+ | |
<!-- BEGIN topicrow --> | |
<!-- IF not topicrow.S_TOPIC_TYPE_SWITCH and not topicrow.S_FIRST_ROW --> | |
@@ -150,7 +152,7 @@ | |
<ul class="topiclist topics"> | |
<!-- ENDIF --> | |
- <!-- EVENT viewforum_body_topic_row_before --> | |
+ <!-- EVENT viewforum_body_topicrow_row_before --> | |
<li class="row<!-- IF topicrow.S_ROW_COUNT is even --> bg1<!-- ELSE --> bg2<!-- ENDIF --><!-- IF topicrow.S_POST_GLOBAL --> global-announce<!-- ENDIF --><!-- IF topicrow.S_POST_ANNOUNCE --> announce<!-- ENDIF --><!-- IF topicrow.S_POST_STICKY --> sticky<!-- ENDIF --><!-- IF topicrow.S_TOPIC_REPORTED --> reported<!-- ENDIF -->"> | |
<!-- EVENT viewforum_body_topic_row_prepend --> | |
<dl class="row-item {topicrow.TOPIC_IMG_STYLE}"> | |
@@ -165,21 +167,22 @@ | |
<!-- ENDIF --> | |
<a href="{topicrow.U_VIEW_TOPIC}" class="topictitle">{topicrow.TOPIC_TITLE}</a> | |
<!-- IF topicrow.S_TOPIC_UNAPPROVED or topicrow.S_POSTS_UNAPPROVED --> | |
- <a href="{topicrow.U_MCP_QUEUE}" title="{TOPIC_UNAPPROVED}"> | |
- <i class="icon fa-question fa-fw icon-blue" aria-hidden="true"></i><span class="sr-only">{TOPIC_UNAPPROVED}</span> | |
+ <a href="{topicrow.U_MCP_QUEUE}" title="{L_TOPIC_UNAPPROVED}"> | |
+ <i class="icon fa-question fa-fw icon-blue" aria-hidden="true"></i><span class="sr-only">{L_TOPIC_UNAPPROVED}</span> | |
</a> | |
<!-- ENDIF --> | |
<!-- IF topicrow.S_TOPIC_DELETED --> | |
- <a href="{topicrow.U_MCP_QUEUE}" title="{TOPIC_DELETED}"> | |
- <i class="icon fa-recycle fa-fw icon-green" aria-hidden="true"></i><span class="sr-only">{TOPIC_DELETED}</span> | |
+ <a href="{topicrow.U_MCP_QUEUE}" title="{L_TOPIC_DELETED}"> | |
+ <i class="icon fa-recycle fa-fw icon-green" aria-hidden="true"></i><span class="sr-only">{L_TOPIC_DELETED}</span> | |
</a> | |
<!-- ENDIF --> | |
<!-- IF topicrow.S_TOPIC_REPORTED --> | |
- <a href="{topicrow.U_MCP_REPORT}" title="{TOPIC_REPORTED}"> | |
- <i class="icon fa-exclamation fa-fw icon-red" aria-hidden="true"></i><span class="sr-only">{TOPIC_REPORTED}</span> | |
+ <a href="{topicrow.U_MCP_REPORT}" title="{L_TOPIC_REPORTED}"> | |
+ <i class="icon fa-exclamation fa-fw icon-red" aria-hidden="true"></i><span class="sr-only">{L_TOPIC_REPORTED}</span> | |
</a> | |
<!-- ENDIF --> | |
<br /> | |
+ <!-- EVENT topiclist_row_topic_title_after --> | |
<!-- IF not S_IS_BOT --> | |
<div class="responsive-show" style="display: none;"> | |
diff --git a/phpBB/styles/prosilver/theme/bidi.css b/phpBB/styles/prosilver/theme/bidi.css | |
index a6d4bef..f09493a 100644 | |
--- a/phpBB/styles/prosilver/theme/bidi.css | |
+++ b/phpBB/styles/prosilver/theme/bidi.css | |
@@ -922,6 +922,7 @@ li.breadcrumbs span:first-child > a { | |
.rtl .search-header .button-search-end { | |
border: 0; | |
+ border-radius: 4px 0 0 4px; | |
} | |
.rtl .search-header { | |
diff --git a/phpBB/styles/prosilver/theme/colours.css b/phpBB/styles/prosilver/theme/colours.css | |
index d76fd08..cf21ac2 100644 | |
--- a/phpBB/styles/prosilver/theme/colours.css | |
+++ b/phpBB/styles/prosilver/theme/colours.css | |
@@ -1168,3 +1168,8 @@ input.disabled { | |
li.notification-reported strong, li.notification-disapproved strong { | |
color: #D31141; | |
} | |
+ | |
+.badge { | |
+ background-color: #D31141; | |
+ color: #ffffff; | |
+} | |
diff --git a/phpBB/styles/prosilver/theme/common.css b/phpBB/styles/prosilver/theme/common.css | |
index e800c63..ee585e6 100644 | |
--- a/phpBB/styles/prosilver/theme/common.css | |
+++ b/phpBB/styles/prosilver/theme/common.css | |
@@ -88,7 +88,9 @@ p.right { | |
} | |
p.jumpbox-return { | |
- margin-top: 1em; | |
+ margin-top: 10px; | |
+ margin-bottom: 0; | |
+ float: left; | |
} | |
b, strong { | |
@@ -1205,6 +1207,22 @@ ul.linklist:after, | |
margin-left: 58px; | |
} | |
+.badge { | |
+ border-radius: 10px; | |
+ opacity: 0.8; | |
+ text-align: center; | |
+ white-space: nowrap; | |
+ font-size: 10px; | |
+ line-height: 1; | |
+ float: right; | |
+ display: inline-block; | |
+ margin-left: 3px; | |
+ vertical-align: baseline; | |
+ position: relative; | |
+ top: 3px; | |
+ padding: 4px 6px; | |
+} | |
+ | |
/* Navbar specific list items | |
----------------------------------------*/ | |
@@ -1216,10 +1234,6 @@ ul.linklist:after, | |
display: none; | |
} | |
-.linklist.compact .rightside > a strong { | |
- padding-left: 2px; | |
-} | |
- | |
.dropdown-page-jump .dropdown { | |
top: 20px; | |
} |
Sign up for free
to join this conversation on GitHub.
Already have an account?
Sign in to comment
diff --git a/phpBB/styles/prosilver/template/ajax.js b/phpBB/styles/prosilver/template/ajax.js | |
index aec6b0b..3888d26 100644 | |
--- a/phpBB/styles/prosilver/template/ajax.js | |
+++ b/phpBB/styles/prosilver/template/ajax.js | |
@@ -132,9 +132,9 @@ phpbb.markNotifications = function($popup, unreadCount) { | |
// Update the unread count. | |
$('strong', '#notification_list_button').html(unreadCount); | |
// Remove the Mark all read link if there are no unread notifications. | |
if (!unreadCount) { | |
- $('#mark_all_notifications').remove(); | |
+ $('#mark_all_notifications, #notification_list_button > strong').remove(); | |
} | |
// Update page title | |
@@ -132,9 +132,9 @@ phpbb.markNotifications = function($popup, unreadCount) { | |
// Update the unread count. | |
$('strong', '#notification_list_button').html(unreadCount); | |
- // Remove the Mark all read link if there are no unread notifications. | |
+ // Remove the Mark all read link & notification count if there are no unread notifications. | |
if (!unreadCount) { | |